==> advanced-clock-plugin_0.5.0-0.tar.gz: advanced-clock-plugin-0.5.0/src/usr/lib/advanced-clock-plugin/clocks/DateTimeClock.py <==
#
# Copyright 2010 Ruediger Gad <r.c.g@gmx.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import cairo
from datetime import datetime
import gtk
import math
import pango

import clock

def get_name():
    return "Date Time Clock"

class DateTimeClock(clock.Clock):
    def __init__(self, drawing_area):
        clock.Clock.__init__(self, drawing_area)

    def draw_clock(self):
        self.context.set_font_size(20)

# Draw date.
        self.context.move_to(2, 16)
        text = str(self.time.day).zfill(2) + "." + str(self.time.month).zfill(2) + "."
        if self.show_seconds :
            y = str(self.time.year)
            if not self.twelve_hour_mode :
                y = y[2:4]
            text = text + y
        
        self.context.text_path(text)

        if self.fill :
            self.context.fill()
        else :
          self.context.stroke()

# Draw time.
        self.context.move_to(2, 35)

        h = self.time.hour
        abrv = "AM"
        if self.twelve_hour_mode :
            if h == 0 :
                h = 12
            elif h > 12 :
                h = h % 12
                abrv = "PM"

        text = str(h).zfill(2) + ":" + str(self.time.minute).zfill(2)
        if self.show_seconds :
            text = text + ":" + str(self.time.second).zfill(2)
        
        self.context.text_path(text)

        if self.fill :
            self.context.fill()
        else :
          self.context.stroke()

        if self.twelve_hour_mode :
            self.context.set_font_size(10)

            if self.show_seconds :
                self.context.move_to(self.char_width * 9, 35)
            else :
                self.context.move_to(self.char_width * 6, 35)
            
            self.context.text_path(abrv)

            if self.fill :
                self.context.fill()
            else :
                self.context.stroke()

    def resize(self):
        ctx = self.drawing_area.create_pango_context()
        fdesc = pango.FontDescription(self.font_name + " 20")  
        metric = ctx.get_metrics(fdesc)
        self.char_width = int(metric.get_approximate_digit_width() / pango.SCALE * 0.7)

        if self.twelve_hour_mode :
            if self.show_seconds :
                self.drawing_area.set_size_request(self.char_width * 11, 36)
            else:
                self.drawing_area.set_size_request(self.char_width * 9, 36)
        else :
            if self.show_seconds :
                self.drawing_area.set_size_request(self.char_width * 9, 36)
            else:
                self.drawing_area.set_size_request(self.char_width * 6, 36)

==> advanced-clock-plugin_0.5.2-0.tar.gz: advanced-clock-plugin-0.5.2/src/usr/lib/advanced-clock-plugin/clocks/DateTimeClock.py <==
#
# Copyright 2010 Ruediger Gad <r.c.g@gmx.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import cairo
from datetime import datetime
import gtk
import math
import pango

import clock

def get_name():
    return "Date Time Clock"

class DateTimeClock(clock.Clock):
    def __init__(self, drawing_area):
        clock.Clock.__init__(self, drawing_area)

    def draw_clock(self):
        self.context.set_font_size(20)

# Draw date.
        self.context.move_to(2, 16)
        text = str(self.time.day).zfill(2) + "." + str(self.time.month).zfill(2) + "."
        if self.show_seconds :
            y = str(self.time.year)
            if not self.twelve_hour_mode :
                y = y[2:4]
            text = text + y
        
        self.context.text_path(text)

        if self.fill :
            self.context.fill()
        else :
          self.context.stroke()

# Draw time.
        self.context.move_to(2, 35)

        h = self.time.hour
        abrv = "AM"
        if self.twelve_hour_mode :
            if h == 0 :
                h = 12
            elif h > 12 :
                h = h % 12
                abrv = "PM"

        text = str(h).zfill(2) + ":" + str(self.time.minute).zfill(2)
        if self.show_seconds :
            text = text + ":" + str(self.time.second).zfill(2)
        
        self.context.text_path(text)

        if self.fill :
            self.context.fill()
        else :
          self.context.stroke()

        if self.twelve_hour_mode :
            self.context.set_font_size(10)
            self.context.move_to(self.text_width, 35)
            
            self.context.text_path(abrv)

            if self.fill :
                self.context.fill()
            else :
                self.context.stroke()

    def resize(self):
        self.context.set_font_size(20)
        if self.show_seconds :
            self.text_width = self.context.text_extents("00:00:00")[2]
        else:
            self.text_width = self.context.text_extents("00:00")[2]

        self.text_width *= 1.1

        if self.twelve_hour_mode :
            self.text_width += self.context.text_extents("..")[2]
            self.context.set_font_size(10)
            self.abrv_width = self.context.text_extents("AM")[2]
            self.abrv_width *= 1.1
        else :
            self.abrv_width = 0

        self.drawing_area.set_size_request(int(self.text_width + self.abrv_width), 36)
